const redis = require('async-redis');
const logger = require('tracer').console();

class RedisClient {

    constructor(host = '127.0.0.1', port = 3306) {
        this.client = null;
        if (!this.config) this.setConf(host, port);
        this.init();
    }

    init() {
        if (!this.config) {
            logger.error('[REDIS MESSAGE]:No configuration, please set!');
        } else {
            const client = redis.createClient(this.config);
            client.on("error", err => logger.error(err));
            client.on("connect", () => logger.log("redis service connected " + this.client.address));
            this.client = client;
        }
    }

    setConf(host, port) {
        if (typeof host !== 'string' || typeof port !== 'number') {
            logger.error('[REDIS MESSAGE]:Configuration error,please check!');
        }
        this.config = [host, port];
    }

    static getInstance(host, port) {
        if (!RedisClient.instance) RedisClient.instance = new RedisClient(host, port);
        return RedisClient.instance;
    }
}

module.exports = RedisClient;




